import Vue from 'vue';
import Router from 'vue-router';
import store from '@/store';
import test from './test';
import system from './system';
import order from './order';
import car from './car';
import personnel from './personnel';
import client from './client';
import supplier from './supplier';
import bill from './bill';
import Home from '@l/Home.vue';
Vue.use(Router);
const router = new Router({
  mode: 'history',
  // base: process.env.NODE_ENV === 'development' ? '' : 'zhwl',
  base: 'zhwl',

  routes: [
    {
      path: '/',
      redirect: '/homeIndex',
    },
    {
      path: '/',
      component: Home,
      children: [
        {
          path: '/homeIndex',
          component: () => import('../views/homeIndex.vue'),
          meta: { title: '系统首页' },
        },
        ...test,
        ...system,
        ...order,
        ...car,
        ...personnel,
        ...client,
        ...supplier,
        ...bill,
      ],
    },
    {
      path: '/login',
      component: () => import('../views/Login.vue'),
      meta: { title: '登录' },
    },
    {
      path: '/404',
      component: () => import('../views/404.vue'),
      meta: { title: '未找到页面' },
    },
    {
      path: '*',
      redirect: '/404',
    },
  ],
});

//使用钩子函数对路由进行权限跳转
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const user = localStorage.getItem('user');
  if (!user && to.path !== '/login') {
    next('/login');
  } else {
    store.commit('setUser', JSON.parse(user), { root: true });
    // 检查下个路由是不是有特殊设置,有的话,就把参数拼在后面
    checkMenuList(to.path);
    next();
  }
});

const checkMenuList = path => {
  let params = sessionStorage.getItem('params');
  if (!params) return;
  params = JSON.parse(params);
  let menuLimit = params['menuLimit'];
  let limit = menuLimit[path];
  if (limit) store.commit('setMenuParams', limit);
  else store.commit('setMenuParams', {});
};
export default router;
